pub struct WorkspaceTrustConfig {
pub allow: Vec<String>,
pub deny: Vec<String>,
}Fields
allow: Vec<String>Workspace roots trusted for normal destructive and external tool posture.
deny: Vec<String>Workspace roots explicitly denied for destructive and external tool posture.