pub fn load_checkpoint() -> Option<CheckpointResume>Expand description
Load the prior-session checkpoint from .hematite/session.json.
Returns None when there is no prior session or it has no real turns.
pub fn load_checkpoint() -> Option<CheckpointResume>Load the prior-session checkpoint from .hematite/session.json.
Returns None when there is no prior session or it has no real turns.