pub struct CheckpointResume {
pub last_goal: String,
pub turn_count: u32,
pub working_files: Vec<String>,
pub last_verify_ok: Option<bool>,
}Expand description
Snapshot of the previous session, surfaced on startup when a workspace is resumed after a restart or crash.
Fields
last_goal: Stringturn_count: u32working_files: Vec<String>last_verify_ok: Option<bool>Auto Trait Implementations
impl Freeze for CheckpointResume
impl RefUnwindSafe for CheckpointResume
impl Send for CheckpointResume
impl Sync for CheckpointResume
impl Unpin for CheckpointResume
impl UnsafeUnpin for CheckpointResume
impl UnwindSafe for CheckpointResume