pub fn redact(input: &str) -> RedactResultExpand description
Apply all redaction patterns to input.
Returns the sanitized text plus a receipt of what was removed.
pub fn redact(input: &str) -> RedactResultApply all redaction patterns to input.
Returns the sanitized text plus a receipt of what was removed.