Module git

Module git 

Functions

create_ghost_snapshot
Takes an “Isolated Ghost Snapshot” by saving the current state to a hidden ref using a temporary Git index. This prevents pollution of the user’s staged changes.
get_active_branch
is_git_repo
revert_from_ghost
Reverts a file to its state in the last Ghost Snapshot.