pub fn get_pricing(model: &str) -> ModelPricingExpand description
Returns the pricing tier for a model based on its ID. Benchmark rates based on standard cloud provider tiers.
pub fn get_pricing(model: &str) -> ModelPricingReturns the pricing tier for a model based on its ID. Benchmark rates based on standard cloud provider tiers.