pub fn spawn_watcher(
tx: Sender<SpecularEvent>,
) -> Result<RecommendedWatcher, Box<dyn Error>>Expand description
Spawns the OS file watcher asynchronously and transmits internal alerts into via the mpsc channel
pub fn spawn_watcher(
tx: Sender<SpecularEvent>,
) -> Result<RecommendedWatcher, Box<dyn Error>>Spawns the OS file watcher asynchronously and transmits internal alerts into via the mpsc channel