pub fn render_prompt_block(tasks: &[HematiteTask]) -> Option<String>Expand description
Compact block injected into the system prompt every turn when tasks exist.
pub fn render_prompt_block(tasks: &[HematiteTask]) -> Option<String>Compact block injected into the system prompt every turn when tasks exist.