Hematite

Struct Hematite 

pub struct Hematite {
    pub connection: Connection,
}
High-level interface for SQL operations

Fields

connection: Connection

Implementations

Source

impl Hematite

pub fn new_in_memory() -> Result<Self>

Create a new database instance with an in-memory database

pub fn new(database_path: &str) -> Result<Self>

Create a new database instance with a file-based database

pub fn execute(&mut self, sql: &str) -> Result<StatementResult>

Execute a SQL statement and return the result

pub fn query(&mut self, sql: &str) -> Result<ResultSet>

Execute a SQL query and return the result set

pub fn query_row<F, R>(&mut self, sql: &str, f: F) -> Result<Option<R>>
where F: FnOnce(&Row) -> Result<R>,

Execute a SQL statement and return the first row of the result

pub fn query_one<T>(&mut self, sql: &str) -> Result<Option<T>>
where T: FromValue,

Execute a SQL statement and return the first column of the first row

pub fn query_as<T>(&mut self, sql: &str) -> Result<Vec<T>>
where T: FromRow,

pub fn query_one_as<T>(&mut self, sql: &str) -> Result<Option<T>>
where T: FromRow,

pub fn prepare(&mut self, sql: &str) -> Result<PreparedStatement>

Prepare a SQL statement for repeated execution

pub fn execute_prepared( &mut self, stmt: &mut PreparedStatement, ) -> Result<StatementResult>

Execute a prepared statement

pub fn execute_result(&mut self, sql: &str) -> Result<ExecutedStatement>

pub fn iter_script<'a>(&'a mut self, sql: &str) -> Result<ScriptIter<'a>>

pub fn transaction(&mut self) -> Result<Transaction<'_>>

Begin a new transaction

pub fn journal_mode(&self) -> Result<JournalMode>

pub fn set_journal_mode(&mut self, journal_mode: JournalMode) -> Result<()>

pub fn checkpoint_wal(&mut self) -> Result<()>

pub fn execute_batch(&mut self, sql: &str) -> Result<()>

Execute multiple SQL statements in sequence