Module plan

Module plan 

Structs

PlanHandoff

Functions

generate_walkthrough
Generates a final walkthrough report for the current session.
get_plan_params
get_walkthrough_params
load_plan_handoff
maintain_plan
Manages a persistent mission plan for the agent in .hematite/PLAN.md.
parse_plan_handoff
save_plan_handoff