Module terminal

Module terminal 

Enums

TerminalName
Known terminal and multiplexer categories derived from environment variables.

Functions

detect_terminal
Detects the active terminal environment using heuristics borrowed from Codex-RS.