Functions
- create_
ghost_ snapshot - Takes an “Isolated Ghost Snapshot” by saving the current state to a hidden ref using a temporary Git index. This prevents pollution of the user’s staged changes.
- get_
active_ branch - is_
git_ repo - revert_
from_ ghost - Reverts a file to its state in the last Ghost Snapshot.