Functions
- create_
ghost_ snapshot - Takes a “Ghost Snapshot” by saving the current state to a hidden ref. This allows for easy rollbacks without creating visible commits or branches.
- get_
active_ branch - is_
git_ repo - revert_
from_ ghost - Reverts a file to its state in the last Ghost Snapshot.