Module git

Module git 

Functions

create_ghost_snapshot
Takes a “Ghost Snapshot” by saving the current state to a hidden ref. This allows for easy rollbacks without creating visible commits or branches.
get_active_branch
is_git_repo
revert_from_ghost
Reverts a file to its state in the last Ghost Snapshot.