create_ghost_snapshot

Function create_ghost_snapshot 

pub fn create_ghost_snapshot(repo_path: &Path) -> Result<()>
Takes a “Ghost Snapshot” by saving the current state to a hidden ref. This allows for easy rollbacks without creating visible commits or branches.