Module instructions

Module instructions 

Structs

InstructionFile

Functions

discover_instruction_files
Discovers instruction files from the current directory up to the root.
render_instructions
Renders instruction files into a prompt section with a limit on characters.