Relational catalog and access-method layer.
Boundary:
- This module owns relational meaning: schemas, rows, primary keys, secondary indexes, and relational codecs.
- It builds on the generic
crate::storageandcrate::btreelayers but should not be part of the future generic fork. - The intended fork point is below this module: keep
storage+btree, replacecatalog,query, andsqlwith the next database model.
Re-exports
pub use catalog::Catalog;pub use column::Column;pub use cursor::IndexCursor;pub use cursor::TableCursor;pub use engine::CatalogEngine;pub use engine::CatalogIntegrityReport;pub use engine::CatalogStorageStats;pub use engine::TableRuntimeMetadata;pub use header::DatabaseHeader;pub use ids::ColumnId;pub use ids::TableId;pub use object::NamedConstraint;pub use object::NamedConstraintKind;pub use object::Trigger;pub use object::TriggerEvent;pub use object::View;pub use record::StoredRow;pub use schema::Schema;pub use serialization::IndexKeyCodec;pub use serialization::RowCodec;pub use serialization::RowSerializer;pub use table::SecondaryIndex;pub use table::Table;pub use types::DataType;pub use types::DateTimeValue;pub use types::DateValue;pub use types::DecimalValue;pub use types::IntervalDaySecondValue;pub use types::IntervalYearMonthValue;pub use types::JournalMode;pub use types::TimeValue;pub use types::TimeWithTimeZoneValue;pub use types::Value;
Modules
- catalog
- Relational catalog manager.
- column
- Column definitions for database tables.
- cursor
- Relational cursors.
- engine
- Catalog storage engine.
- header
- Database header management for Hematite database.
- ids
- ID types for database objects
- object
- Schema-level relational objects beyond base tables.
- record
- Relational row container used by catalog access methods.
- row_id
- Rowid table cell formats for relational tables.
- schema
- Schema management for database metadata
- serialization
- Relational row and index-key encoding.
- table
- Table definitions for database tables
- tests
- types
- Data types and runtime values for the relational layer.