Structs
Functions
- generate_
walkthrough - Generates a final walkthrough report for the current session.
- get_
plan_ params - get_
walkthrough_ params - load_
plan_ handoff - maintain_
plan - Manages a persistent mission plan for the agent in
.hematite/PLAN.md. - parse_
plan_ handoff - save_
plan_ handoff